@@ -37,13 +37,14 @@ QAction* saveAsAction(Purpose::Menu* menu)
     }
 
     Q_ASSERT(!"Couldn't find the saveas plugin");
-    return Q_NULLPTR;
+    return nullptr;
 }
 
 void MenuTest::runJobTest()
 {
     Purpose::Menu* menu = new Purpose::Menu;
     Purpose::AlternativesModel* model = menu->model();
+    model->setDisabledPlugins({});
 
     const QString tempfile = QStandardPaths::writableLocation(QStandardPaths::TempLocation) + QStringLiteral("/purposetest");
     QFile::remove(tempfile);
