@@ -69,8 +69,8 @@ Q_PROPERTY(QJsonArray neededArguments READ neededArguments CONSTANT)
  */
 Q_PROPERTY(QUrl configSourceCode READ configSourceCode CONSTANT)
 public:
-    Configuration(const QJsonObject &inputData, const QString &pluginTypeName, const QJsonObject &pluginType, const KPluginMetaData &pluginInformation, QObject* parent = Q_NULLPTR);
-    Configuration(const QJsonObject &inputData, const QString &pluginTypeName, const KPluginMetaData &pluginInformation, QObject* parent = Q_NULLPTR);
+    Configuration(const QJsonObject &inputData, const QString &pluginTypeName, const QJsonObject &pluginType, const KPluginMetaData &pluginInformation, QObject* parent = nullptr);
+    Configuration(const QJsonObject &inputData, const QString &pluginTypeName, const KPluginMetaData &pluginInformation, QObject* parent = nullptr);
     ~Configuration() Q_DECL_OVERRIDE;
 
     void setData(const QJsonObject& data);
@@ -80,9 +80,25 @@ public:
     QJsonArray neededArguments() const;
     QUrl configSourceCode() const;
 
+    /**
+     * @returns whether the job will be run in the same process.
+     *
+     * By default it will be true, unless the environment variable KDE_PURPOSE_LOCAL_JOBS is defined
+     */
     bool useSeparateProcess() const;
-    void setUseSeparateProcess(bool);
 
+    /**
+     * @p separate will specify whether the process will be forced to execute
+     * in-process or in a separate process.
+     */
+    void setUseSeparateProcess(bool separate);
+
+    /**
+     * @returns the configured job ready to be started.
+     *
+     * Before calling it, make sure that all information has been filled by
+     * checking isReady().
+     */
     Q_SCRIPTABLE Purpose::Job* createJob();
 
 Q_SIGNALS:
