@@ -36,7 +36,7 @@ Q_GLOBAL_STATIC_WITH_ARGS(const QUrl, imageImgurUrl, (QLatin1String("https://api
 Q_GLOBAL_STATIC_WITH_ARGS(const QUrl, albumImgurUrl, (QLatin1String("https://api.imgur.com/3/album")))
 
 // key associated with aleixpol@kde.org
-Q_GLOBAL_STATIC_WITH_ARGS(const QString, YOUR_CLIENT_ID, (QLatin1String("0bffa5b4ac8383c")));
+Q_GLOBAL_STATIC_WITH_ARGS(const QString, YOUR_CLIENT_ID, (QLatin1String("0bffa5b4ac8383c")))
 
 class ImgurShareJob : public Purpose::Job
 {
@@ -47,7 +47,7 @@ class ImgurShareJob : public Purpose::Job
             , m_pendingJobs(0)
         {}
 
-        virtual void start() override
+        void start() override
         {
             m_pendingJobs = 0;
             const QJsonArray urls = data().value(QStringLiteral("urls")).toArray();
@@ -166,7 +166,7 @@ class Q_DECL_EXPORT ImgurPlugin : public Purpose::PluginBase
     public:
         ImgurPlugin(QObject* p, const QVariantList& ) : Purpose::PluginBase(p) {}
 
-        virtual Purpose::Job* createJob() const override
+        Purpose::Job* createJob() const override
         {
             return new ImgurShareJob(nullptr);
         }
