@@ -26,7 +26,7 @@ class PhabricatorPurposeQuickPlugin : public QQmlExtensionPlugin
     Q_PLUGIN_METADATA(IID "org.qt-project.Qt.QQmlExtensionInterface")
 
 public:
-    virtual void registerTypes(const char* uri) Q_DECL_OVERRIDE;
+    void registerTypes(const char* uri) Q_DECL_OVERRIDE;
 };
 
 #endif // PHABRICATORPURPOSEQUICKPLUGIN_H
