@@ -18,8 +18,9 @@
 #ifndef PURPOSEMENU_H
 #define PURPOSEMENU_H
 
+#include "purposewidgets_export.h"
+
 #include <QMenu>
-#include <purpose/purpose_export.h>
 
 namespace Purpose
 {
@@ -27,13 +28,21 @@ class MenuPrivate;
 
 class AlternativesModel;
 
-class PURPOSE_EXPORT Menu : public QMenu
+class PURPOSEWIDGETS_EXPORT Menu : public QMenu
 {
 Q_OBJECT
 public:
-    Menu(QWidget* parent = Q_NULLPTR);
+    Menu(QWidget* parent = nullptr);
 
+    /**
+     * Exposes the used AlternativesModel so that it can be configured to suit
+     * the application needs
+     */
     AlternativesModel* model() const;
+
+    /**
+     * Forces a reload of the menu in case something changed in the model
+     */
     void reload();
 
 Q_SIGNALS:
